Simple bots or Simbots is a library designed to create simple chat bots using the power of python. This library utilises Intent, Entity, Relation and Context
model to create bots .
Its Basic functions :- 
 
1) Uses machine learning to create Intents . 
2) Supports multiple ways of creating entities and relations . 
3) Also provides helper functions to query context stack .
4) Provides a framework to create text based chatbots .
5) Provides a framework to define test conversation of the bot and test it .
6) Support saving and loading existing conversation .
7) Support saving and loading trained Chatbot .

To install simply use 

    pip install simbots

Links
 
 1) [Documentation](https://vaibhavrr1.github.io/simbots/index.html) 
 2) [pypi](https://pypi.org/project/simbots/)
 3) [github](https://github.com/vaibhavrr1/simbots)
 
 
 